# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/errdetails/v1alpha/fenl_diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/errdetails/v1alpha/fenl_diagnostics.proto',
  package='kaskada.errdetails.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\036com.kaskada.errdetails.v1alphaP\001ZAgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x12\x1akaskada.errdetails.v1alpha\"\x87\x01\n\x0f\x46\x65nlDiagnostics\x12U\n\x10\x66\x65nl_diagnostics\x18\x01 \x03(\x0b\x32*.kaskada.errdetails.v1alpha.FenlDiagnosticR\x0f\x66\x65nlDiagnostics\x12\x1d\n\nnum_errors\x18\x02 \x01(\x03R\tnumErrors\"\xc7\x01\n\x0e\x46\x65nlDiagnostic\x12@\n\x08severity\x18\x01 \x01(\x0e\x32$.kaskada.errdetails.v1alpha.SeverityR\x08severity\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\'\n\x0fsource_location\x18\x04 \x01(\tR\x0esourceLocation\x12\x1c\n\tformatted\x18\x05 \x01(\tR\tformatted*\x86\x01\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x10\n\x0cSEVERITY_BUG\x10\x01\x12\x12\n\x0eSEVERITY_ERROR\x10\x02\x12\x14\n\x10SEVERITY_WARNING\x10\x03\x12\x11\n\rSEVERITY_NOTE\x10\x04\x12\x11\n\rSEVERITY_HELP\x10\x05\x42\x65\n\x1e\x63om.kaskada.errdetails.v1alphaP\x01ZAgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alphab\x06proto3'
)

_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='kaskada.errdetails.v1alpha.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_BUG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_WARNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_NOTE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_HELP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=422,
  serialized_end=556,
)
_sym_db.RegisterEnumDescriptor(_SEVERITY)

Severity = enum_type_wrapper.EnumTypeWrapper(_SEVERITY)
SEVERITY_UNSPECIFIED = 0
SEVERITY_BUG = 1
SEVERITY_ERROR = 2
SEVERITY_WARNING = 3
SEVERITY_NOTE = 4
SEVERITY_HELP = 5



_FENLDIAGNOSTICS = _descriptor.Descriptor(
  name='FenlDiagnostics',
  full_name='kaskada.errdetails.v1alpha.FenlDiagnostics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fenl_diagnostics', full_name='kaskada.errdetails.v1alpha.FenlDiagnostics.fenl_diagnostics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fenlDiagnostics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_errors', full_name='kaskada.errdetails.v1alpha.FenlDiagnostics.num_errors', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numErrors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=217,
)


_FENLDIAGNOSTIC = _descriptor.Descriptor(
  name='FenlDiagnostic',
  full_name='kaskada.errdetails.v1alpha.FenlDiagnostic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.severity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='severity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_location', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.source_location', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatted', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.formatted', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='formatted', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=419,
)

_FENLDIAGNOSTICS.fields_by_name['fenl_diagnostics'].message_type = _FENLDIAGNOSTIC
_FENLDIAGNOSTIC.fields_by_name['severity'].enum_type = _SEVERITY
DESCRIPTOR.message_types_by_name['FenlDiagnostics'] = _FENLDIAGNOSTICS
DESCRIPTOR.message_types_by_name['FenlDiagnostic'] = _FENLDIAGNOSTIC
DESCRIPTOR.enum_types_by_name['Severity'] = _SEVERITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FenlDiagnostics = _reflection.GeneratedProtocolMessageType('FenlDiagnostics', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTICS,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostics)
  })
_sym_db.RegisterMessage(FenlDiagnostics)

FenlDiagnostic = _reflection.GeneratedProtocolMessageType('FenlDiagnostic', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTIC,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostic)
  })
_sym_db.RegisterMessage(FenlDiagnostic)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/view.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/view.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ekaskada/api/v1alpha/view.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xbb\x01\n\x04View\x12\x1d\n\x07view_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x06viewId\x12$\n\tview_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\x12\'\n\nexpression\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12\x45\n\x0bresult_type\x18\x07 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeB\x04\xe2\x41\x01\x03R\nresultType\"*\n\x10ListViewsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\"\x92\x01\n\x11ListViewsResponse\x12/\n\x05views\x18\x01 \x03(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x05views\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"6\n\x0eGetViewRequest\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\"\x8e\x01\n\x0fGetViewResponse\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x04view\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"L\n\x11\x43reateViewRequest\x12\x37\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04view\"\xcc\x01\n\x12\x43reateViewResponse\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x04view\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"9\n\x11\x44\x65leteViewRequest\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\"b\n\x12\x44\x65leteViewResponse\x12L\n\x0frequest_details\x18\x01 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x80\x04\n\x0bViewService\x12r\n\tListViews\x12%.kaskada.api.v1alpha.ListViewsRequest\x1a&.kaskada.api.v1alpha.ListViewsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1alpha/views\x12z\n\x07GetView\x12#.kaskada.api.v1alpha.GetViewRequest\x1a$.kaskada.api.v1alpha.GetViewResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1alpha/views/{view_name=*}\x12{\n\nCreateView\x12&.kaskada.api.v1alpha.CreateViewRequest\x1a\'.kaskada.api.v1alpha.CreateViewResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x0e/v1alpha/views:\x04view\x12\x83\x01\n\nDeleteView\x12&.kaskada.api.v1alpha.DeleteViewRequest\x1a\'.kaskada.api.v1alpha.DeleteViewResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1alpha/views/{view_name=*}BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_VIEW = _descriptor.Descriptor(
  name='View',
  full_name='kaskada.api.v1alpha.View',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_id', full_name='kaskada.api.v1alpha.View.view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='viewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_name', full_name='kaskada.api.v1alpha.View.view_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expression', full_name='kaskada.api.v1alpha.View.expression', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='expression', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_type', full_name='kaskada.api.v1alpha.View.result_type', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='resultType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=400,
)


_LISTVIEWSREQUEST = _descriptor.Descriptor(
  name='ListViewsRequest',
  full_name='kaskada.api.v1alpha.ListViewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListViewsRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=444,
)


_LISTVIEWSRESPONSE = _descriptor.Descriptor(
  name='ListViewsResponse',
  full_name='kaskada.api.v1alpha.ListViewsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='views', full_name='kaskada.api.v1alpha.ListViewsResponse.views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='views', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListViewsResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=593,
)


_GETVIEWREQUEST = _descriptor.Descriptor(
  name='GetViewRequest',
  full_name='kaskada.api.v1alpha.GetViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_name', full_name='kaskada.api.v1alpha.GetViewRequest.view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=649,
)


_GETVIEWRESPONSE = _descriptor.Descriptor(
  name='GetViewResponse',
  full_name='kaskada.api.v1alpha.GetViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='kaskada.api.v1alpha.GetViewResponse.view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetViewResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=794,
)


_CREATEVIEWREQUEST = _descriptor.Descriptor(
  name='CreateViewRequest',
  full_name='kaskada.api.v1alpha.CreateViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='kaskada.api.v1alpha.CreateViewRequest.view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', json_name='view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=872,
)


_CREATEVIEWRESPONSE = _descriptor.Descriptor(
  name='CreateViewResponse',
  full_name='kaskada.api.v1alpha.CreateViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='kaskada.api.v1alpha.CreateViewResponse.view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateViewResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.CreateViewResponse.analysis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=1079,
)


_DELETEVIEWREQUEST = _descriptor.Descriptor(
  name='DeleteViewRequest',
  full_name='kaskada.api.v1alpha.DeleteViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_name', full_name='kaskada.api.v1alpha.DeleteViewRequest.view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1138,
)


_DELETEVIEWRESPONSE = _descriptor.Descriptor(
  name='DeleteViewResponse',
  full_name='kaskada.api.v1alpha.DeleteViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.DeleteViewResponse.request_details', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1140,
  serialized_end=1238,
)

_VIEW.fields_by_name['result_type'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._DATATYPE
_LISTVIEWSRESPONSE.fields_by_name['views'].message_type = _VIEW
_LISTVIEWSRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETVIEWRESPONSE.fields_by_name['view'].message_type = _VIEW
_GETVIEWRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEVIEWREQUEST.fields_by_name['view'].message_type = _VIEW
_CREATEVIEWRESPONSE.fields_by_name['view'].message_type = _VIEW
_CREATEVIEWRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEVIEWRESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_DELETEVIEWRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['View'] = _VIEW
DESCRIPTOR.message_types_by_name['ListViewsRequest'] = _LISTVIEWSREQUEST
DESCRIPTOR.message_types_by_name['ListViewsResponse'] = _LISTVIEWSRESPONSE
DESCRIPTOR.message_types_by_name['GetViewRequest'] = _GETVIEWREQUEST
DESCRIPTOR.message_types_by_name['GetViewResponse'] = _GETVIEWRESPONSE
DESCRIPTOR.message_types_by_name['CreateViewRequest'] = _CREATEVIEWREQUEST
DESCRIPTOR.message_types_by_name['CreateViewResponse'] = _CREATEVIEWRESPONSE
DESCRIPTOR.message_types_by_name['DeleteViewRequest'] = _DELETEVIEWREQUEST
DESCRIPTOR.message_types_by_name['DeleteViewResponse'] = _DELETEVIEWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
  'DESCRIPTOR' : _VIEW,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.View)
  })
_sym_db.RegisterMessage(View)

ListViewsRequest = _reflection.GeneratedProtocolMessageType('ListViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListViewsRequest)
  })
_sym_db.RegisterMessage(ListViewsRequest)

ListViewsResponse = _reflection.GeneratedProtocolMessageType('ListViewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListViewsResponse)
  })
_sym_db.RegisterMessage(ListViewsResponse)

GetViewRequest = _reflection.GeneratedProtocolMessageType('GetViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetViewRequest)
  })
_sym_db.RegisterMessage(GetViewRequest)

GetViewResponse = _reflection.GeneratedProtocolMessageType('GetViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetViewResponse)
  })
_sym_db.RegisterMessage(GetViewResponse)

CreateViewRequest = _reflection.GeneratedProtocolMessageType('CreateViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateViewRequest)
  })
_sym_db.RegisterMessage(CreateViewRequest)

CreateViewResponse = _reflection.GeneratedProtocolMessageType('CreateViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateViewResponse)
  })
_sym_db.RegisterMessage(CreateViewResponse)

DeleteViewRequest = _reflection.GeneratedProtocolMessageType('DeleteViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteViewRequest)
  })
_sym_db.RegisterMessage(DeleteViewRequest)

DeleteViewResponse = _reflection.GeneratedProtocolMessageType('DeleteViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteViewResponse)
  })
_sym_db.RegisterMessage(DeleteViewResponse)


DESCRIPTOR._options = None
_VIEW.fields_by_name['view_id']._options = None
_VIEW.fields_by_name['view_name']._options = None
_VIEW.fields_by_name['expression']._options = None
_VIEW.fields_by_name['result_type']._options = None
_GETVIEWREQUEST.fields_by_name['view_name']._options = None
_CREATEVIEWREQUEST.fields_by_name['view']._options = None
_DELETEVIEWREQUEST.fields_by_name['view_name']._options = None

_VIEWSERVICE = _descriptor.ServiceDescriptor(
  name='ViewService',
  full_name='kaskada.api.v1alpha.ViewService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1241,
  serialized_end=1753,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListViews',
    full_name='kaskada.api.v1alpha.ViewService.ListViews',
    index=0,
    containing_service=None,
    input_type=_LISTVIEWSREQUEST,
    output_type=_LISTVIEWSRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1alpha/views',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetView',
    full_name='kaskada.api.v1alpha.ViewService.GetView',
    index=1,
    containing_service=None,
    input_type=_GETVIEWREQUEST,
    output_type=_GETVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1alpha/views/{view_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateView',
    full_name='kaskada.api.v1alpha.ViewService.CreateView',
    index=2,
    containing_service=None,
    input_type=_CREATEVIEWREQUEST,
    output_type=_CREATEVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\016/v1alpha/views:\004view',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteView',
    full_name='kaskada.api.v1alpha.ViewService.DeleteView',
    index=3,
    containing_service=None,
    input_type=_DELETEVIEWREQUEST,
    output_type=_DELETEVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\036*\034/v1alpha/views/{view_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIEWSERVICE)

DESCRIPTOR.services_by_name['ViewService'] = _VIEWSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/staged_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/staged_file.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%kaskada/api/v1alpha/staged_file.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a kaskada/api/v1alpha/shared.proto\x1a\x17validate/validate.proto\"\xff\x02\n\nStagedFile\x12\x1d\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x06\x66ileId\x12$\n\tfile_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x66ileName\x12\x41\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12T\n\x15upload_completed_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x13uploadCompletedTime\x12*\n\ncontent_id\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01 \xd0\x01\x01R\tcontentId\x12+\n\x0e\x63ontent_length\x18\x06 \x01(\x03\x42\x04\xe2\x41\x01\x03R\rcontentLength\x12:\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x04\xe2\x41\x01\x03R\x06schema\"x\n\x16ListStagedFilesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc6\x01\n\x17ListStagedFilesResponse\x12\x35\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x05\x66iles\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"8\n\x14GetStagedFileRequest\x12 \n\x07\x66ile_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x66ileId\"\x9a\x01\n\x15GetStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"X\n\x17\x43reateStagedFileRequest\x12=\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04\x66ile\"\xaf\x01\n\x18\x43reateStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\xcc\x03\n\x11StagedFileService\x12\x8b\x01\n\x0fListStagedFiles\x12+.kaskada.api.v1alpha.ListStagedFilesRequest\x1a,.kaskada.api.v1alpha.ListStagedFilesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1alpha/staged_files\x12\x91\x01\n\rGetStagedFile\x12).kaskada.api.v1alpha.GetStagedFileRequest\x1a*.kaskada.api.v1alpha.GetStagedFileResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1alpha/staged_files/{file_id=*}\x12\x94\x01\n\x10\x43reateStagedFile\x12,.kaskada.api.v1alpha.CreateStagedFileRequest\x1a-.kaskada.api.v1alpha.CreateStagedFileResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x15/v1alpha/staged_files:\x04\x66ileBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STAGEDFILE = _descriptor.Descriptor(
  name='StagedFile',
  full_name='kaskada.api.v1alpha.StagedFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='kaskada.api.v1alpha.StagedFile.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='kaskada.api.v1alpha.StagedFile.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='fileName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.StagedFile.create_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_completed_time', full_name='kaskada.api.v1alpha.StagedFile.upload_completed_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='uploadCompletedTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_id', full_name='kaskada.api.v1alpha.StagedFile.content_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\230\001 \320\001\001', json_name='contentId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_length', full_name='kaskada.api.v1alpha.StagedFile.content_length', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='contentLength', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.StagedFile.schema', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=636,
)


_LISTSTAGEDFILESREQUEST = _descriptor.Descriptor(
  name='ListStagedFilesRequest',
  full_name='kaskada.api.v1alpha.ListStagedFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListStagedFilesRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='kaskada.api.v1alpha.ListStagedFilesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\032\005\030\350\007(\000', json_name='pageSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='kaskada.api.v1alpha.ListStagedFilesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=758,
)


_LISTSTAGEDFILESRESPONSE = _descriptor.Descriptor(
  name='ListStagedFilesResponse',
  full_name='kaskada.api.v1alpha.ListStagedFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='kaskada.api.v1alpha.ListStagedFilesResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='files', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='kaskada.api.v1alpha.ListStagedFilesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextPageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListStagedFilesResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=959,
)


_GETSTAGEDFILEREQUEST = _descriptor.Descriptor(
  name='GetStagedFileRequest',
  full_name='kaskada.api.v1alpha.GetStagedFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='kaskada.api.v1alpha.GetStagedFileRequest.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1017,
)


_GETSTAGEDFILERESPONSE = _descriptor.Descriptor(
  name='GetStagedFileResponse',
  full_name='kaskada.api.v1alpha.GetStagedFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.GetStagedFileResponse.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetStagedFileResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1174,
)


_CREATESTAGEDFILEREQUEST = _descriptor.Descriptor(
  name='CreateStagedFileRequest',
  full_name='kaskada.api.v1alpha.CreateStagedFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.CreateStagedFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1264,
)


_CREATESTAGEDFILERESPONSE = _descriptor.Descriptor(
  name='CreateStagedFileResponse',
  full_name='kaskada.api.v1alpha.CreateStagedFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.CreateStagedFileResponse.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='kaskada.api.v1alpha.CreateStagedFileResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='url', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateStagedFileResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1442,
)

_STAGEDFILE.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STAGEDFILE.fields_by_name['upload_completed_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STAGEDFILE.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_LISTSTAGEDFILESRESPONSE.fields_by_name['files'].message_type = _STAGEDFILE
_LISTSTAGEDFILESRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETSTAGEDFILERESPONSE.fields_by_name['file'].message_type = _STAGEDFILE
_GETSTAGEDFILERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATESTAGEDFILEREQUEST.fields_by_name['file'].message_type = _STAGEDFILE
_CREATESTAGEDFILERESPONSE.fields_by_name['file'].message_type = _STAGEDFILE
_CREATESTAGEDFILERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['StagedFile'] = _STAGEDFILE
DESCRIPTOR.message_types_by_name['ListStagedFilesRequest'] = _LISTSTAGEDFILESREQUEST
DESCRIPTOR.message_types_by_name['ListStagedFilesResponse'] = _LISTSTAGEDFILESRESPONSE
DESCRIPTOR.message_types_by_name['GetStagedFileRequest'] = _GETSTAGEDFILEREQUEST
DESCRIPTOR.message_types_by_name['GetStagedFileResponse'] = _GETSTAGEDFILERESPONSE
DESCRIPTOR.message_types_by_name['CreateStagedFileRequest'] = _CREATESTAGEDFILEREQUEST
DESCRIPTOR.message_types_by_name['CreateStagedFileResponse'] = _CREATESTAGEDFILERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StagedFile = _reflection.GeneratedProtocolMessageType('StagedFile', (_message.Message,), {
  'DESCRIPTOR' : _STAGEDFILE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.StagedFile)
  })
_sym_db.RegisterMessage(StagedFile)

ListStagedFilesRequest = _reflection.GeneratedProtocolMessageType('ListStagedFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesRequest)
  })
_sym_db.RegisterMessage(ListStagedFilesRequest)

ListStagedFilesResponse = _reflection.GeneratedProtocolMessageType('ListStagedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesResponse)
  })
_sym_db.RegisterMessage(ListStagedFilesResponse)

GetStagedFileRequest = _reflection.GeneratedProtocolMessageType('GetStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileRequest)
  })
_sym_db.RegisterMessage(GetStagedFileRequest)

GetStagedFileResponse = _reflection.GeneratedProtocolMessageType('GetStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileResponse)
  })
_sym_db.RegisterMessage(GetStagedFileResponse)

CreateStagedFileRequest = _reflection.GeneratedProtocolMessageType('CreateStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileRequest)
  })
_sym_db.RegisterMessage(CreateStagedFileRequest)

CreateStagedFileResponse = _reflection.GeneratedProtocolMessageType('CreateStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileResponse)
  })
_sym_db.RegisterMessage(CreateStagedFileResponse)


DESCRIPTOR._options = None
_STAGEDFILE.fields_by_name['file_id']._options = None
_STAGEDFILE.fields_by_name['file_name']._options = None
_STAGEDFILE.fields_by_name['create_time']._options = None
_STAGEDFILE.fields_by_name['upload_completed_time']._options = None
_STAGEDFILE.fields_by_name['content_id']._options = None
_STAGEDFILE.fields_by_name['content_length']._options = None
_STAGEDFILE.fields_by_name['schema']._options = None
_LISTSTAGEDFILESREQUEST.fields_by_name['page_size']._options = None
_GETSTAGEDFILEREQUEST.fields_by_name['file_id']._options = None
_CREATESTAGEDFILEREQUEST.fields_by_name['file']._options = None

_STAGEDFILESERVICE = _descriptor.ServiceDescriptor(
  name='StagedFileService',
  full_name='kaskada.api.v1alpha.StagedFileService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1445,
  serialized_end=1905,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListStagedFiles',
    full_name='kaskada.api.v1alpha.StagedFileService.ListStagedFiles',
    index=0,
    containing_service=None,
    input_type=_LISTSTAGEDFILESREQUEST,
    output_type=_LISTSTAGEDFILESRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1alpha/staged_files',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStagedFile',
    full_name='kaskada.api.v1alpha.StagedFileService.GetStagedFile',
    index=1,
    containing_service=None,
    input_type=_GETSTAGEDFILEREQUEST,
    output_type=_GETSTAGEDFILERESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/v1alpha/staged_files/{file_id=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStagedFile',
    full_name='kaskada.api.v1alpha.StagedFileService.CreateStagedFile',
    index=2,
    containing_service=None,
    input_type=_CREATESTAGEDFILEREQUEST,
    output_type=_CREATESTAGEDFILERESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\025/v1alpha/staged_files:\004file',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STAGEDFILESERVICE)

DESCRIPTOR.services_by_name['StagedFileService'] = _STAGEDFILESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/api.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dkaskada/api/v1alpha/api.proto\x12\x13kaskada.api.v1alphaBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
)



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/fenl/v1alpha/schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/fenl/v1alpha/schema.proto',
  package='kaskada.fenl.v1alpha',
  syntax='proto3',
  serialized_options=b'Z;gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!kaskada/fenl/v1alpha/schema.proto\x12\x14kaskada.fenl.v1alpha\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x07\n\x08\x44\x61taType\x12L\n\tprimitive\x18\x01 \x01(\x0e\x32,.kaskada.fenl.v1alpha.DataType.PrimitiveTypeH\x00R\tprimitive\x12\x36\n\x06struct\x18\x02 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaH\x00R\x06struct\x12\x30\n\x06window\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x06window\"\x90\x06\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13PRIMITIVE_TYPE_NULL\x10\x01\x12\x17\n\x13PRIMITIVE_TYPE_BOOL\x10\x02\x12\x15\n\x11PRIMITIVE_TYPE_I8\x10\x03\x12\x16\n\x12PRIMITIVE_TYPE_I16\x10\x04\x12\x16\n\x12PRIMITIVE_TYPE_I32\x10\x05\x12\x16\n\x12PRIMITIVE_TYPE_I64\x10\x06\x12\x15\n\x11PRIMITIVE_TYPE_U8\x10\x07\x12\x16\n\x12PRIMITIVE_TYPE_U16\x10\x08\x12\x16\n\x12PRIMITIVE_TYPE_U32\x10\t\x12\x16\n\x12PRIMITIVE_TYPE_U64\x10\n\x12\x16\n\x12PRIMITIVE_TYPE_F16\x10\x0b\x12\x16\n\x12PRIMITIVE_TYPE_F32\x10\x0c\x12\x16\n\x12PRIMITIVE_TYPE_F64\x10\r\x12\x19\n\x15PRIMITIVE_TYPE_STRING\x10\x0e\x12$\n PRIMITIVE_TYPE_INTERVAL_DAY_TIME\x10\x0f\x12&\n\"PRIMITIVE_TYPE_INTERVAL_YEAR_MONTH\x10\x10\x12\"\n\x1ePRIMITIVE_TYPE_DURATION_SECOND\x10\x11\x12\'\n#PRIMITIVE_TYPE_DURATION_MILLISECOND\x10\x12\x12\'\n#PRIMITIVE_TYPE_DURATION_MICROSECOND\x10\x13\x12&\n\"PRIMITIVE_TYPE_DURATION_NANOSECOND\x10\x14\x12#\n\x1fPRIMITIVE_TYPE_TIMESTAMP_SECOND\x10\x15\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MILLISECOND\x10\x16\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MICROSECOND\x10\x17\x12\'\n#PRIMITIVE_TYPE_TIMESTAMP_NANOSECOND\x10\x18\x42\x06\n\x04kind\"\x9e\x01\n\x06Schema\x12:\n\x06\x66ields\x18\x01 \x03(\x0b\x32\".kaskada.fenl.v1alpha.Schema.FieldR\x06\x66ields\x1aX\n\x05\x46ield\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\tdata_type\x18\x02 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeR\x08\x64\x61taTypeB=Z;gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_DATATYPE_PRIMITIVETYPE = _descriptor.EnumDescriptor(
  name='PrimitiveType',
  full_name='kaskada.fenl.v1alpha.DataType.PrimitiveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_NULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_BOOL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I8', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I16', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I32', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I64', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U8', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U16', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U32', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U64', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_F16', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_F32', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_F64', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_STRING', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_INTERVAL_DAY_TIME', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_INTERVAL_YEAR_MONTH', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_SECOND', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_MILLISECOND', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_MICROSECOND', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_NANOSECOND', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_SECOND', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_MILLISECOND', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_MICROSECOND', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_NANOSECOND', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=286,
  serialized_end=1070,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE_PRIMITIVETYPE)


_DATATYPE = _descriptor.Descriptor(
  name='DataType',
  full_name='kaskada.fenl.v1alpha.DataType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive', full_name='kaskada.fenl.v1alpha.DataType.primitive', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='primitive', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='struct', full_name='kaskada.fenl.v1alpha.DataType.struct', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='struct', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='kaskada.fenl.v1alpha.DataType.window', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='window', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATATYPE_PRIMITIVETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='kaskada.fenl.v1alpha.DataType.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89,
  serialized_end=1078,
)


_SCHEMA_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='kaskada.fenl.v1alpha.Schema.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.fenl.v1alpha.Schema.Field.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='kaskada.fenl.v1alpha.Schema.Field.data_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1239,
)

_SCHEMA = _descriptor.Descriptor(
  name='Schema',
  full_name='kaskada.fenl.v1alpha.Schema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='kaskada.fenl.v1alpha.Schema.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fields', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCHEMA_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1239,
)

_DATATYPE.fields_by_name['primitive'].enum_type = _DATATYPE_PRIMITIVETYPE
_DATATYPE.fields_by_name['struct'].message_type = _SCHEMA
_DATATYPE.fields_by_name['window'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_DATATYPE_PRIMITIVETYPE.containing_type = _DATATYPE
_DATATYPE.oneofs_by_name['kind'].fields.append(
  _DATATYPE.fields_by_name['primitive'])
_DATATYPE.fields_by_name['primitive'].containing_oneof = _DATATYPE.oneofs_by_name['kind']
_DATATYPE.oneofs_by_name['kind'].fields.append(
  _DATATYPE.fields_by_name['struct'])
_DATATYPE.fields_by_name['struct'].containing_oneof = _DATATYPE.oneofs_by_name['kind']
_DATATYPE.oneofs_by_name['kind'].fields.append(
  _DATATYPE.fields_by_name['window'])
_DATATYPE.fields_by_name['window'].containing_oneof = _DATATYPE.oneofs_by_name['kind']
_SCHEMA_FIELD.fields_by_name['data_type'].message_type = _DATATYPE
_SCHEMA_FIELD.containing_type = _SCHEMA
_SCHEMA.fields_by_name['fields'].message_type = _SCHEMA_FIELD
DESCRIPTOR.message_types_by_name['DataType'] = _DATATYPE
DESCRIPTOR.message_types_by_name['Schema'] = _SCHEMA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataType = _reflection.GeneratedProtocolMessageType('DataType', (_message.Message,), {
  'DESCRIPTOR' : _DATATYPE,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.DataType)
  })
_sym_db.RegisterMessage(DataType)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMA_FIELD,
    '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema.Field)
    })
  ,
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema)
  })
_sym_db.RegisterMessage(Schema)
_sym_db.RegisterMessage(Schema.Field)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/table.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fkaskada/api/v1alpha/table.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xd3\x04\n\x05Table\x12\x1f\n\x08table_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x07tableId\x12&\n\ntable_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x31\n\x10time_column_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0etimeColumnName\x12<\n\x16\x65ntity_key_column_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13\x65ntityKeyColumnName\x12\x37\n\x13subsort_column_name\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x11subsortColumnName\x12\x1f\n\x0bgrouping_id\x18\x07 \x01(\tR\ngroupingId\x12\x41\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x1e\n\x07version\x18\n \x01(\x05\x42\x04\xe2\x41\x01\x03R\x07version\x12#\n\nold_schema\x18\x0b \x01(\tB\x04\xe2\x41\x01\x03R\toldSchema\x12:\n\x06schema\x18\r \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x04\xe2\x41\x01\x03R\x06schema\x12#\n\nfile_count\x18\x0e \x01(\x03\x42\x04\xe2\x41\x01\x03R\tfileCountJ\x04\x08\x06\x10\x07J\x04\x08\x0c\x10\r\"|\n\nSourceData\x12:\n\x04\x66ile\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.SourceData.FileH\x00R\x04\x66ile\x1a*\n\x04\x46ile\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02idB\x06\n\x04\x64\x61ta\"\x96\x02\n\x13TableVersionDetails\x12\x18\n\x07version\x18\x01 \x01(\x05R\x07version\x12\x41\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x1c\n\x06schema\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x06schema\x12P\n\nfile_infos\x18\x05 \x03(\x0b\x32\x31.kaskada.api.v1alpha.TableVersionDetails.FileInfoR\tfileInfos\x1a,\n\x08\x46ileInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n\x03key\x18\x02 \x01(\tR\x03keyJ\x04\x08\x04\x10\x05\"s\n\x11ListTablesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xbe\x01\n\x12ListTablesResponse\x12\x32\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x06tables\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"9\n\x0fGetTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x92\x01\n\x10GetTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"P\n\x12\x43reateTableRequest\x12:\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x05table\"\x95\x01\n\x13\x43reateTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"<\n\x12\x44\x65leteTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x87\x01\n\x13\x44\x65leteTableResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"\xc2\x01\n\x0fLoadDataRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\"\n\x07\x66ile_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x06\x66ileId\x12O\n\x10\x65xternal_s3_file\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.ExternalS3FileH\x00R\x0e\x65xternalS3FileB\x12\n\x0bsource_data\x12\x03\xf8\x42\x01\"\x84\x01\n\x10LoadDataResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x94\x05\n\x0cTableService\x12v\n\nListTables\x12&.kaskada.api.v1alpha.ListTablesRequest\x1a\'.kaskada.api.v1alpha.ListTablesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/tables\x12\x7f\n\x08GetTable\x12$.kaskada.api.v1alpha.GetTableRequest\x1a%.kaskada.api.v1alpha.GetTableResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/tables/{table_name=*}\x12\x80\x01\n\x0b\x43reateTable\x12\'.kaskada.api.v1alpha.CreateTableRequest\x1a(.kaskada.api.v1alpha.CreateTableResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x0f/v1alpha/tables:\x05table\x12\x88\x01\n\x0b\x44\x65leteTable\x12\'.kaskada.api.v1alpha.DeleteTableRequest\x1a(.kaskada.api.v1alpha.DeleteTableResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1alpha/tables/{table_name=*}\x12}\n\x08LoadData\x12$.kaskada.api.v1alpha.LoadDataRequest\x1a%.kaskada.api.v1alpha.LoadDataResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1alpha/tables/load_data:\x01*BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TABLE = _descriptor.Descriptor(
  name='Table',
  full_name='kaskada.api.v1alpha.Table',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='kaskada.api.v1alpha.Table.table_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='tableId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.Table.table_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_column_name', full_name='kaskada.api.v1alpha.Table.time_column_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='timeColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity_key_column_name', full_name='kaskada.api.v1alpha.Table.entity_key_column_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='entityKeyColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsort_column_name', full_name='kaskada.api.v1alpha.Table.subsort_column_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='subsortColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grouping_id', full_name='kaskada.api.v1alpha.Table.grouping_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='groupingId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.Table.create_time', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='kaskada.api.v1alpha.Table.update_time', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='updateTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='kaskada.api.v1alpha.Table.version', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_schema', full_name='kaskada.api.v1alpha.Table.old_schema', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='oldSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.Table.schema', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_count', full_name='kaskada.api.v1alpha.Table.file_count', index=11,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='fileCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=842,
)


_SOURCEDATA_FILE = _descriptor.Descriptor(
  name='File',
  full_name='kaskada.api.v1alpha.SourceData.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.api.v1alpha.SourceData.File.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='kaskada.api.v1alpha.SourceData.File.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=918,
  serialized_end=960,
)

_SOURCEDATA = _descriptor.Descriptor(
  name='SourceData',
  full_name='kaskada.api.v1alpha.SourceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.SourceData.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOURCEDATA_FILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='kaskada.api.v1alpha.SourceData.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=844,
  serialized_end=968,
)


_TABLEVERSIONDETAILS_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='kaskada.api.v1alpha.TableVersionDetails.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='kaskada.api.v1alpha.TableVersionDetails.FileInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='kaskada.api.v1alpha.TableVersionDetails.FileInfo.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1243,
)

_TABLEVERSIONDETAILS = _descriptor.Descriptor(
  name='TableVersionDetails',
  full_name='kaskada.api.v1alpha.TableVersionDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='kaskada.api.v1alpha.TableVersionDetails.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.TableVersionDetails.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.TableVersionDetails.schema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_infos', full_name='kaskada.api.v1alpha.TableVersionDetails.file_infos', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileInfos', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TABLEVERSIONDETAILS_FILEINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1249,
)


_LISTTABLESREQUEST = _descriptor.Descriptor(
  name='ListTablesRequest',
  full_name='kaskada.api.v1alpha.ListTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListTablesRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='kaskada.api.v1alpha.ListTablesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\032\005\030\350\007(\000', json_name='pageSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='kaskada.api.v1alpha.ListTablesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1366,
)


_LISTTABLESRESPONSE = _descriptor.Descriptor(
  name='ListTablesResponse',
  full_name='kaskada.api.v1alpha.ListTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tables', full_name='kaskada.api.v1alpha.ListTablesResponse.tables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tables', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='kaskada.api.v1alpha.ListTablesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextPageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListTablesResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1559,
)


_GETTABLEREQUEST = _descriptor.Descriptor(
  name='GetTableRequest',
  full_name='kaskada.api.v1alpha.GetTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.GetTableRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=1618,
)


_GETTABLERESPONSE = _descriptor.Descriptor(
  name='GetTableResponse',
  full_name='kaskada.api.v1alpha.GetTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='kaskada.api.v1alpha.GetTableResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetTableResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1621,
  serialized_end=1767,
)


_CREATETABLEREQUEST = _descriptor.Descriptor(
  name='CreateTableRequest',
  full_name='kaskada.api.v1alpha.CreateTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='kaskada.api.v1alpha.CreateTableRequest.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1849,
)


_CREATETABLERESPONSE = _descriptor.Descriptor(
  name='CreateTableResponse',
  full_name='kaskada.api.v1alpha.CreateTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='kaskada.api.v1alpha.CreateTableResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateTableResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=2001,
)


_DELETETABLEREQUEST = _descriptor.Descriptor(
  name='DeleteTableRequest',
  full_name='kaskada.api.v1alpha.DeleteTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.DeleteTableRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2063,
)


_DELETETABLERESPONSE = _descriptor.Descriptor(
  name='DeleteTableResponse',
  full_name='kaskada.api.v1alpha.DeleteTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.DeleteTableResponse.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.DeleteTableResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2066,
  serialized_end=2201,
)


_LOADDATAREQUEST = _descriptor.Descriptor(
  name='LoadDataRequest',
  full_name='kaskada.api.v1alpha.LoadDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.LoadDataRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_id', full_name='kaskada.api.v1alpha.LoadDataRequest.file_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_s3_file', full_name='kaskada.api.v1alpha.LoadDataRequest.external_s3_file', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='externalS3File', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source_data', full_name='kaskada.api.v1alpha.LoadDataRequest.source_data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2204,
  serialized_end=2398,
)


_LOADDATARESPONSE = _descriptor.Descriptor(
  name='LoadDataResponse',
  full_name='kaskada.api.v1alpha.LoadDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.LoadDataResponse.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.LoadDataResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2401,
  serialized_end=2533,
)

_TABLE.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_SOURCEDATA_FILE.containing_type = _SOURCEDATA
_SOURCEDATA.fields_by_name['file'].message_type = _SOURCEDATA_FILE
_SOURCEDATA.oneofs_by_name['data'].fields.append(
  _SOURCEDATA.fields_by_name['file'])
_SOURCEDATA.fields_by_name['file'].containing_oneof = _SOURCEDATA.oneofs_by_name['data']
_TABLEVERSIONDETAILS_FILEINFO.containing_type = _TABLEVERSIONDETAILS
_TABLEVERSIONDETAILS.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLEVERSIONDETAILS.fields_by_name['file_infos'].message_type = _TABLEVERSIONDETAILS_FILEINFO
_LISTTABLESRESPONSE.fields_by_name['tables'].message_type = _TABLE
_LISTTABLESRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETTABLERESPONSE.fields_by_name['table'].message_type = _TABLE
_GETTABLERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATETABLEREQUEST.fields_by_name['table'].message_type = _TABLE
_CREATETABLERESPONSE.fields_by_name['table'].message_type = _TABLE
_CREATETABLERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_DELETETABLERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_LOADDATAREQUEST.fields_by_name['external_s3_file'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._EXTERNALS3FILE
_LOADDATAREQUEST.oneofs_by_name['source_data'].fields.append(
  _LOADDATAREQUEST.fields_by_name['file_id'])
_LOADDATAREQUEST.fields_by_name['file_id'].containing_oneof = _LOADDATAREQUEST.oneofs_by_name['source_data']
_LOADDATAREQUEST.oneofs_by_name['source_data'].fields.append(
  _LOADDATAREQUEST.fields_by_name['external_s3_file'])
_LOADDATAREQUEST.fields_by_name['external_s3_file'].containing_oneof = _LOADDATAREQUEST.oneofs_by_name['source_data']
_LOADDATARESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['Table'] = _TABLE
DESCRIPTOR.message_types_by_name['SourceData'] = _SOURCEDATA
DESCRIPTOR.message_types_by_name['TableVersionDetails'] = _TABLEVERSIONDETAILS
DESCRIPTOR.message_types_by_name['ListTablesRequest'] = _LISTTABLESREQUEST
DESCRIPTOR.message_types_by_name['ListTablesResponse'] = _LISTTABLESRESPONSE
DESCRIPTOR.message_types_by_name['GetTableRequest'] = _GETTABLEREQUEST
DESCRIPTOR.message_types_by_name['GetTableResponse'] = _GETTABLERESPONSE
DESCRIPTOR.message_types_by_name['CreateTableRequest'] = _CREATETABLEREQUEST
DESCRIPTOR.message_types_by_name['CreateTableResponse'] = _CREATETABLERESPONSE
DESCRIPTOR.message_types_by_name['DeleteTableRequest'] = _DELETETABLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteTableResponse'] = _DELETETABLERESPONSE
DESCRIPTOR.message_types_by_name['LoadDataRequest'] = _LOADDATAREQUEST
DESCRIPTOR.message_types_by_name['LoadDataResponse'] = _LOADDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table)
  })
_sym_db.RegisterMessage(Table)

SourceData = _reflection.GeneratedProtocolMessageType('SourceData', (_message.Message,), {

  'File' : _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
    'DESCRIPTOR' : _SOURCEDATA_FILE,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.SourceData.File)
    })
  ,
  'DESCRIPTOR' : _SOURCEDATA,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.SourceData)
  })
_sym_db.RegisterMessage(SourceData)
_sym_db.RegisterMessage(SourceData.File)

TableVersionDetails = _reflection.GeneratedProtocolMessageType('TableVersionDetails', (_message.Message,), {

  'FileInfo' : _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
    'DESCRIPTOR' : _TABLEVERSIONDETAILS_FILEINFO,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails.FileInfo)
    })
  ,
  'DESCRIPTOR' : _TABLEVERSIONDETAILS,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails)
  })
_sym_db.RegisterMessage(TableVersionDetails)
_sym_db.RegisterMessage(TableVersionDetails.FileInfo)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

DeleteTableRequest = _reflection.GeneratedProtocolMessageType('DeleteTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableRequest)
  })
_sym_db.RegisterMessage(DeleteTableRequest)

DeleteTableResponse = _reflection.GeneratedProtocolMessageType('DeleteTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableResponse)
  })
_sym_db.RegisterMessage(DeleteTableResponse)

LoadDataRequest = _reflection.GeneratedProtocolMessageType('LoadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATAREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataRequest)
  })
_sym_db.RegisterMessage(LoadDataRequest)

LoadDataResponse = _reflection.GeneratedProtocolMessageType('LoadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATARESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataResponse)
  })
_sym_db.RegisterMessage(LoadDataResponse)


DESCRIPTOR._options = None
_TABLE.fields_by_name['table_id']._options = None
_TABLE.fields_by_name['table_name']._options = None
_TABLE.fields_by_name['time_column_name']._options = None
_TABLE.fields_by_name['entity_key_column_name']._options = None
_TABLE.fields_by_name['subsort_column_name']._options = None
_TABLE.fields_by_name['create_time']._options = None
_TABLE.fields_by_name['update_time']._options = None
_TABLE.fields_by_name['version']._options = None
_TABLE.fields_by_name['old_schema']._options = None
_TABLE.fields_by_name['schema']._options = None
_TABLE.fields_by_name['file_count']._options = None
_TABLEVERSIONDETAILS.fields_by_name['create_time']._options = None
_TABLEVERSIONDETAILS.fields_by_name['schema']._options = None
_LISTTABLESREQUEST.fields_by_name['page_size']._options = None
_GETTABLEREQUEST.fields_by_name['table_name']._options = None
_CREATETABLEREQUEST.fields_by_name['table']._options = None
_DELETETABLEREQUEST.fields_by_name['table_name']._options = None
_LOADDATAREQUEST.oneofs_by_name['source_data']._options = None
_LOADDATAREQUEST.fields_by_name['table_name']._options = None
_LOADDATAREQUEST.fields_by_name['file_id']._options = None

_TABLESERVICE = _descriptor.ServiceDescriptor(
  name='TableService',
  full_name='kaskada.api.v1alpha.TableService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2536,
  serialized_end=3196,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTables',
    full_name='kaskada.api.v1alpha.TableService.ListTables',
    index=0,
    containing_service=None,
    input_type=_LISTTABLESREQUEST,
    output_type=_LISTTABLESRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1alpha/tables',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTable',
    full_name='kaskada.api.v1alpha.TableService.GetTable',
    index=1,
    containing_service=None,
    input_type=_GETTABLEREQUEST,
    output_type=_GETTABLERESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1alpha/tables/{table_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTable',
    full_name='kaskada.api.v1alpha.TableService.CreateTable',
    index=2,
    containing_service=None,
    input_type=_CREATETABLEREQUEST,
    output_type=_CREATETABLERESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\017/v1alpha/tables:\005table',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTable',
    full_name='kaskada.api.v1alpha.TableService.DeleteTable',
    index=3,
    containing_service=None,
    input_type=_DELETETABLEREQUEST,
    output_type=_DELETETABLERESPONSE,
    serialized_options=b'\202\323\344\223\002 *\036/v1alpha/tables/{table_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadData',
    full_name='kaskada.api.v1alpha.TableService.LoadData',
    index=4,
    containing_service=None,
    input_type=_LOADDATAREQUEST,
    output_type=_LOADDATARESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\031/v1alpha/tables/load_data:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TABLESERVICE)

DESCRIPTOR.services_by_name['TableService'] = _TABLESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/prepare/v1alpha/slice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/prepare/v1alpha/slice.proto',
  package='kaskada.prepare.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\033com.kaskada.prepare.v1alphaP\001Z>gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/prepare/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#kaskada/prepare/v1alpha/slice.proto\x12\x17kaskada.prepare.v1alpha\"\x91\x01\n\x0cSliceRequest\x12N\n\x07percent\x18\x01 \x01(\x0b\x32\x32.kaskada.prepare.v1alpha.SliceRequest.PercentSliceH\x00R\x07percent\x1a(\n\x0cPercentSlice\x12\x18\n\x07percent\x18\x01 \x01(\x01R\x07percentB\x07\n\x05sliceB_\n\x1b\x63om.kaskada.prepare.v1alphaP\x01Z>gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/prepare/v1alphab\x06proto3'
)




_SLICEREQUEST_PERCENTSLICE = _descriptor.Descriptor(
  name='PercentSlice',
  full_name='kaskada.prepare.v1alpha.SliceRequest.PercentSlice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percent', full_name='kaskada.prepare.v1alpha.SliceRequest.PercentSlice.percent', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='percent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=201,
)

_SLICEREQUEST = _descriptor.Descriptor(
  name='SliceRequest',
  full_name='kaskada.prepare.v1alpha.SliceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percent', full_name='kaskada.prepare.v1alpha.SliceRequest.percent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='percent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SLICEREQUEST_PERCENTSLICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='slice', full_name='kaskada.prepare.v1alpha.SliceRequest.slice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=65,
  serialized_end=210,
)

_SLICEREQUEST_PERCENTSLICE.containing_type = _SLICEREQUEST
_SLICEREQUEST.fields_by_name['percent'].message_type = _SLICEREQUEST_PERCENTSLICE
_SLICEREQUEST.oneofs_by_name['slice'].fields.append(
  _SLICEREQUEST.fields_by_name['percent'])
_SLICEREQUEST.fields_by_name['percent'].containing_oneof = _SLICEREQUEST.oneofs_by_name['slice']
DESCRIPTOR.message_types_by_name['SliceRequest'] = _SLICEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SliceRequest = _reflection.GeneratedProtocolMessageType('SliceRequest', (_message.Message,), {

  'PercentSlice' : _reflection.GeneratedProtocolMessageType('PercentSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEREQUEST_PERCENTSLICE,
    '__module__' : 'kaskada.prepare.v1alpha.slice_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.prepare.v1alpha.SliceRequest.PercentSlice)
    })
  ,
  'DESCRIPTOR' : _SLICEREQUEST,
  '__module__' : 'kaskada.prepare.v1alpha.slice_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.prepare.v1alpha.SliceRequest)
  })
_sym_db.RegisterMessage(SliceRequest)
_sym_db.RegisterMessage(SliceRequest.PercentSlice)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
